## Description

<!-- Briefly describe what this PR does and why -->

## Type of Change

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)
- [ ] Performance improvement
- [ ] Tests (adding or updating tests)

## Related Issues

<!-- Link to related issues -->
Fixes #
Related to #

## How This Has Been Tested

<!-- Describe the tests you ran and how to reproduce them -->

- [ ] Unit tests added/updated
- [ ] Integration tests added/updated
- [ ] All tests pass locally: `uv run pytest`
- [ ] Coverage ≥ 90%: `uv run pytest --cov=better_py`

## Test Results

<!-- Paste test results or link to CI run -->

## Checklist

- [ ] My code follows the style guidelines of this project (ruff, mypy pass)
- [ ] I have performed a self-review of my own code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published

## Breaking Changes

<!-- If this PR introduces breaking changes, describe them here -->

## Additional Notes

<!-- Add any other notes or context -->

## Screenshots (if applicable)

<!-- Add screenshots if this PR changes UI or behavior -->
